#!/usr/bin/env bash

# Copyright 2008 Red Hat Inc., Durham, North Carolina.
# All Rights Reserved.
#
# OpenScap SEAP Test Suite.
#
# Created on: Nov 30, 2009
#
# Authors:
#      David Niemoller
#      Ondrej Moris <omoris@redhat.com>

. ${srcdir}/test_common.sh

# Setup.
function test_seap_setup {
    local ret_val=0
    return $ret_val
}

# Test Cases.

# Parsing incorrect expression.
function test_seap_incorrect_expression {
    local ret_val=0;
    
    ARGS=( 
	"18446744073709551616" \
	"111111111111111111111" \
	"1e" \
	"11e" \
	"111e" \
	"1111e" \
	"11111e" \
	"111111e" \
	"1111111e" \
	"11111111e" \
	"111111111e" \
	"11111111111111111111111111111111111111111e" \
	"-1e" \
	"-11e" \
	"-111e" \
	"-1111e" \
	"-11111e" \
	"-111111e" \
	"-1111111e" \
	"-11111111e" \
	"+1e" \
	"+11e" \
	"+111e" \
	"+1111ee" \
	"+11111e" \
	"+111111e" \
	"+1111111e" \
	"+11111111e" \
	"+111111111e" \
	".12e1.2" \
	"3.-12" \
	"+12.1-1" \
	"0.12.3" \
	"+0.1.23" \
	"-0.12.3" \
	".123." \
	"+.123." \
	"-.123." \
	".0." \
	"1.." \
	"-1.e" \
	"+1.e" \
	"12.4e" \
	"-12.4e" \
	"+12.3e" \
	"1e2.4" \
	"1e-2.4" \
	"1e+2.4" \
	"12e1.4" \
	"12e-1.4" \
	"12e+1.4" \
	"1e12.4" \
	"1e-12.4" \
	"1e+12.4" \
	"1E2.4" \
	"1E-2.4" \
	"1E+2.4" \
	"12E1.4" \
	"12E-1.4" \
	"12E+1.4" \
	"1E12.4" \
	"1E-12.4" \
	"1E+12.4" \
	"123.3e3.4" \
	"-12.3e3.4" \
	"+12.3e3.4" \
	"123.3e-3.4" \
	"123.3e+3.4" \
	"-12.3e-3.4" \
	"+12.3e+3.4" \
	"(a" \
	"(aa" \
	"(aaa" \
	"(aaaa" \
	"(aaaaa" \
	"(aaaaaa" \
	"(aaaaaaa" \
	"(aaaaaaaa" \
	"\"(a b c)" \
	"\"(aa b cc)" \
	"aaa b c)" \
	"aa bb b)" \
	"a 1 2)" \
	"1 2 (a" \
	"'simple" \
	"'\"test\"" \
	"[INT8123" \
	"[UINT8]123)" \
	"[url]http://example.com\"" \
	"[simple string])hello" \
	"#40414243" \
	"#4041424#)" \
	"#4#)" \
	")#4#" \
	"#akjsd#" \
	"#234afg#" \
	"(#404#" \
	"[hex])#414243#" \
	"|TWFu|)" \
	"([base64]))|TWFu|" \
	"|TW9ua2V5Cg==|))" \
	"|TW9ua2V5Cg|(" \
	"|YmFzZTY0KE1vbmtleSkgPSB8VFc5dWEyVjVDZ3wK|)" \
	"(msg :id 123 (test \"abcd\") 123 [url]\"http://www.example.com\"))" \
	"(msg (:id 123 :hash [md5]|PNeg23b/ncpIl54kw5tAjA==| (test 123 \"asdf\" [wtf]\"dlskflskdf\"))" \
	"(msg :id 123(test 123 \"asdf \"bla\"))" \
	"(msg :id 123(test 123\"asdf\"\"bla))" 
	)

    for I in "${ARGS[@]}"; do
	./sexp_parser $I > test_seap_tc01.out
	ret_val=$[$ret_val+$?]
    done 

    if [ $ret_val -eq ${#ARGS[@]} ]; then
	ret_val=0
    else
	ret_val=1
    fi

    return $ret_val
}

function test_seap_string_expression {
    local ret_val=0;

    ./sexp_string > test_seap_tc02.out
    ret_val=$?

    return $ret_val
}

function test_seap_number_expression {
    local ret_val=0;

    ./sexp_number >> test_seap_tc02.out
    ret_val=$?

    return $ret_val
}

function test_seap_list_expression {
    local ret_val=0;

    ./sexp_list >> test_seap_tc02.out
    ret_val=$?

    return $ret_val
}

# Parsing correct expression.
function test_seap_correct_expression {
    local ret_val=0;

    ARGS=(
	"0" \
	"1" \
	"11" \
	"111" \
	"1111" \
	"11111" \
	"111111" \
	"1111111" \
	"11111111" \
	"111111111" \
	"1111111111" \
	"99999999999" \
	"18446744073709551615" \
	"9223372036854775807" \
	"9223372036854775808" \
	"-9223372036854775807" \
	"-9223372036854775808" \
	"4294967295" \
	"4294967296" \
	"2147483647" \
	"2147483648" \
	"-2147483647" \
	"-2147483648" \
	"65535" \
	"65536" \
	"131071" \
	"131072" \
	"-131071" \
	"-131072" \
	"255" \
	"256" \
	"127" \
	"128" \
	"-127" \
	"-128" \
	"-1" \
	"-11" \
	"-111" \
	"-1111" \
	"-11111" \
	"-111111" \
	"-1111111" \
	"-11111111" \
	"+1" \
	"+11" \
	"+111" \
	"+1111" \
	"+11111" \
	"+111111" \
	"+1111111" \
	"+11111111" \
	"+111111111" \
	"12" \
	"-12" \
	"+12" \
	"0.123" \
	"+0.123" \
	"-0.123" \
	".123" \
	"+.123" \
	"-.123" \
	".0" \
	"1." \
	"-1." \
	"+1." \
	"12." \
	"-12." \
	"+12." \
	"1e2" \
	"1e-2" \
	"1e+2" \
	"12e1" \
	"12e-1" \
	"12e+1" \
	"1e12" \
	"1e-12" \
	"1e+12" \
	"1E2" \
	"1E-2" \
	"1E+2" \
	"12E1" \
	"12E-1" \
	"12E+1" \
	"1E12" \
	"1E-12" \
	"1E+12" \
	"123.3e3" \
	"-12.3e3" \
	"+12.3e3" \
	"123.3e-3" \
	"123.3e+3" \
	"-12.3e-3" \
	"+12.3e+3" \
	"a" \
	"aa" \
	"aaa" \
	"aaaa" \
	"aaaaa" \
	"aaaaaa" \
	"aaaaaaa" \
	"aaaaaaaa" \
	"\"(a b c)\"" \
	"\"(aa b cc)\"" \
	"aaa b c" \
	"aa bb b" \
	"a 1 2" \
	"1 a 2" \
	"1 2 a" \
	"'simple'" \ 
	"'\"test\"'" \
	"[INT8]123" \
	"[UINT8]123" \
	"[url]\"http://example.com\"" \
	"[simple string]hello" \
	"#40414243#" \
	"#4041424#" \
	"#4#" \
	"#404#" \
	"[hex]#414243#" \
	"|TWFu|" \
	"[base64]|TWFu|" \
	"|TW9ua2V5Cg==|" \
	"|TW9ua2V5Cg|" \
	"|YmFzZTY0KE1vbmtleSkgPSB8VFc5dWEyVjVDZ3wK|" \
	"(msg :id 123 (test \"abcd\" 123 [url]\"http://www.example.com\"))" \
	"(msg :id 123 :hash [md5]|PNeg23b/ncpIl54kw5tAjA==| (test 123 \"asdf\" [wtf]\"dlskflskdf\"))" \
	"(msg :id 123(test 123 \"asdf\" \"bla\"))" \
	"(msg :id 123(test 123\"asdf\"\"bla\"))" \
	"(msg)" \
	"(\"\" \"a\" \"aa\" \"aaa\" \"aaaa\" \"aaaaa\")" \
	"(\"\"(\"\")\"\")" \
	"(\"asdf\"(\"asdf\")\"asdf\")" \
	"(m(m)m)" \
	"(a(a a)a)" \
	"(a())" \
	"((((((()))))))" \
	"()()()()()()()" \
	"()()()()()()" \
	"()()()()()" \
	"()()()()" \
	"()()" \
	"()" \
	"()(())((()))()" \
	"(1(2(3(4(5(6(7)))))))" \
	"[a]b" \
	"[a]b[c]d" \
	"[asdf](1 2 3 4)" \
	"[num]([int]1 [int]2 [char]'c' [string]\"asdf\")" \
	"1:a" \
	"3:abc" \
	"4:abc\"" \
	"4:\"abc" \
	"7:a c d e" \
	"1:a1:b1:c" \
	"2:ab2:cd" \
	"(1:a2:bc)" \
	"4|TWFu|" \
	"(4|TWFu|4|TWFu|)" \
	"4[type]4:abcd" \
	"(4[type]3:123)" \
	"4#4142#" \
	"4#4142#4#4142#" \
	"(4#4142#)" \
	"3#414#" \
	"(3#414#)"
    )

    for I in "${ARGS[@]}"; do
	./sexp_parser "$I" > test_seap_tc01.out
	ret_val=$[$ret_val+$?]
	./sexp_parser "($I)" >> test_seap_tc01.out
	ret_val=$[$ret_val+$?]
	./sexp_parser "( $I)" >> test_seap_tc01.out
	ret_val=$[$ret_val+$?]
	./sexp_parser "($I )" >> test_seap_tc01.out
	ret_val=$[$ret_val+$?]
	./sexp_parser "( $I )" >> test_seap_tc01.out
	ret_val=$[$ret_val+$?]
    done 

    return $ret_val
}

function test_seap_split {
    local ret_val=0;
    local SPLITSEQ="257 511 1200 4096 5111 10001 45348"
    # hardcore test
    # local SPLITSEQ=$(seq 1 524288)
    local TEMPDIR="$(mktemp -d -t tmp.XXXXXX)"
    local LOGFILE="test_seap_tc05.out"
    local EXECDIR="$(pwd)"
    cd "$TEMPDIR"

    for b in $SPLITSEQ; do
	split -a 6 -b $b - x <<EOF
(8:seap.msg 3::id 1 9::reply-id 0 ((9:file_item (4:path 4:/var ) (8:filename 4:mail ) (4:type 9:directory ) (8:group_id 2:12 ) (7:user_id 1:0 ) (6:a_time 10:1262574187 ) (6:c_time 10:1262574187 ) (6:m_time 10:1262574187 ) (4:size 4096 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]1 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/tmp ) (8:filename 8:.X0-lock ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1254209896 ) (6:c_time 10:1252497722 ) (6:m_time 10:1252497722 ) (4:size 11 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/tmp ) (8:filename 10:krb5cc_500 ) (4:type 7:regular ) (8:group_id 3:500 ) (7:user_id 3:500 ) (6:a_time 10:1262610002 ) (6:c_time 10:1259764578 ) (6:m_time 10:1259764578 ) (4:size 453 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/usr ) (8:filename 3:tmp ) (4:type 9:directory ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257956157 ) (6:c_time 10:1262574193 ) (6:m_time 10:1262574193 ) (4:size 4096 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]1 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]1 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]1 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 6:/media ) (8:filename 9:.hal-mtab ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261415370 ) (6:c_time 10:1261415370 ) (6:m_time 10:1261415370 ) (4:size 0 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 6:/media ) (8:filename 14:.hal-mtab-lock ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252497747 ) (6:c_time 10:1252497747 ) (6:m_time 10:1252497747 ) (4:size 0 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/bin ) (8:filename 10:traceroute ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449472 ) (6:m_time 10:1241449472 ) (4:size 51120 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 3:sed ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610010 ) (6:c_time 10:1241449475 ) (6:m_time 10:1241449475 ) (4:size 53548 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 10:tracepath6 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241447976 ) (6:m_time 10:1241447976 ) (4:size 10816 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:cp ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608963 ) (6:c_time 10:1241449496 ) (6:m_time 10:1241449496 ) (4:size 106852 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 3:rpm ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262574188 ) (6:c_time 10:1257476713 ) (6:m_time 10:1257476713 ) (4:size 23048 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 9:tracepath ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241447976 ) (6:m_time 10:1241447976 ) (4:size 10052 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 8:hostname ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 12268 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 8:dumpkeys ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449485 ) (6:m_time 10:1241449485 ) (4:size 59120 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:ls ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610010 ) (6:c_time 10:1241449460 ) (6:m_time 10:1241449460 ) (4:size 115932 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 8:kbd_mode ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449488 ) (6:m_time 10:1241449488 ) (4:size 7916 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 3:cut ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449413 ) (6:m_time 10:1241449413 ) (4:size 50408 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 3:awk ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608935 ) (6:c_time 10:1241449446 ) (6:m_time 10:1241449446 ) (4:size 337712 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 3:tar ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1248833057 ) (6:m_time 10:1248833057 ) (4:size 284264 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:find ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608923 ) (6:c_time 10:1241449446 ) (6:m_time 10:1241449446 ) (4:size 161192 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 12:unicode_stop ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1204025146 ) (6:c_time 10:1241448263 ) (6:m_time 10:1241448263 ) (4:size 79 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:mknod ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449458 ) (6:m_time 10:1241449458 ) (4:size 37500 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:zcat ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262489256 ) (6:c_time 10:1241444103 ) (6:m_time 10:1241444103 ) (4:size 62 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:chgrp ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449490 ) (6:m_time 10:1241449490 ) (4:size 58424 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 3:pwd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608870 ) (6:c_time 10:1241449427 ) (6:m_time 10:1241449427 ) (4:size 36116 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 7:netstat ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 119760 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 10:domainname ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 12268 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:mail ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1257476688 ) (6:m_time 10:1257476688 ) (4:size 366292 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:chmod ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608922 ) (6:c_time 10:1241449462 ) (6:m_time 10:1241449462 ) (4:size 54976 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:mailx ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1257476688 ) (6:m_time 10:1257476688 ) (4:size 366292 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 8:basename ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608894 ) (6:c_time 10:1241449489 ) (6:m_time 10:1241449489 ) (4:size 31880 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 10:mountpoint ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449426 ) (6:m_time 10:1241449426 ) (4:size 7320 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 11:traceroute6 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449472 ) (6:m_time 10:1241449472 ) (4:size 51120 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:fgrep ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1241449456 ) (6:m_time 10:1241449456 ) (4:size 85612 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:mv ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608935 ) (6:c_time 10:1241449459 ) (6:m_time 10:1241449459 ) (4:size 96836 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:sleep ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608884 ) (6:c_time 10:1241449485 ) (6:m_time 10:1241449485 ) (4:size 32264 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 15:ulockmgr_server ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1257476686 ) (6:m_time 10:1257476686 ) (4:size 11124 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 3:rvi ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449459 ) (6:m_time 10:1241449459 ) (4:size 697592 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 12:ypdomainname ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 12268 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:gtar ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1248833057 ) (6:m_time 10:1248833057 ) (4:size 284264 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 6:usleep ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449485 ) (6:m_time 10:1241449485 ) (4:size 6884 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:sh ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610010 ) (6:c_time 10:1241449463 ) (6:m_time 10:1241449463 ) (4:size 756360 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:login ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1246327407 ) (6:m_time 10:1246327407 ) (4:size 25904 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 13:dnsdomainname ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 12268 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 20:dbus-cleanup-sockets ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1248833057 ) (6:m_time 10:1248833057 ) (4:size 9692 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:gzip ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609705 ) (6:c_time 10:1241449482 ) (6:m_time 10:1241449482 ) (4:size 64524 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:nice ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262236684 ) (6:c_time 10:1241449496 ) (6:m_time 10:1241449496 ) (4:size 33784 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 9:setserial ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449436 ) (6:m_time 10:1241449436 ) (4:size 20800 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:egrep ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1241449456 ) (6:m_time 10:1241449456 ) (4:size 85612 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 13:unicode_start ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241448263 ) (6:m_time 10:1241448263 ) (4:size 1273 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 11:dbus-daemon ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1248778254 ) (6:m_time 10:1248778254 ) (4:size 334352 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 3:red ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449424 ) (6:m_time 10:1241449424 ) (4:size 45704 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:chown ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449463 ) (6:m_time 10:1241449463 ) (4:size 60620 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:ln ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608923 ) (6:c_time 10:1241449461 ) (6:m_time 10:1241449461 ) (4:size 51616 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:more ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1245722611 ) (6:m_time 10:1245722611 ) (4:size 35076 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:cpio ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449428 ) (6:m_time 10:1241449428 ) (4:size 129696 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:rm ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609705 ) (6:c_time 10:1241449460 ) (6:m_time 10:1241449460 ) (4:size 59868 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:sort ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608923 ) (6:c_time 10:1241449459 ) (6:m_time 10:1241449459 ) (4:size 94504 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 7:setfont ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449425 ) (6:m_time 10:1241449425 ) (4:size 36332 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:df ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262574187 ) (6:c_time 10:1241449497 ) (6:m_time 10:1241449497 ) (4:size 76288 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:ex ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449459 ) (6:m_time 10:1241449459 ) (4:size 697592 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 3:env ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608934 ) (6:c_time 10:1241449477 ) (6:m_time 10:1241449477 ) (4:size 31124 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:rview ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449459 ) (6:m_time 10:1241449459 ) (4:size 697592 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 6:ipcalc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449466 ) (6:m_time 10:1241449466 ) (4:size 9976 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 9:ntfsmount ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449431 ) (6:m_time 10:1241449431 ) (4:size 36844 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:arch ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608884 ) (6:c_time 10:1241449458 ) (6:m_time 10:1241449458 ) (4:size 33540 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 8:plymouth ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449426 ) (6:m_time 10:1241449426 ) (4:size 22428 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:uname ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608935 ) (6:c_time 10:1241449482 ) (6:m_time 10:1241449482 ) (4:size 33540 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 6:unlink ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449472 ) (6:m_time 10:1241449472 ) (4:size 30912 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 7:gettext ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1243995125 ) (6:m_time 10:1243995125 ) (4:size 26996 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:dd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 61116 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:link ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449488 ) (6:m_time 10:1241449488 ) (4:size 31100 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 13:nisdomainname ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 12268 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 7:taskset ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1245722608 ) (6:m_time 10:1245722608 ) (4:size 11896 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 12:dbus-uuidgen ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1248833044 ) (6:m_time 10:1248833044 ) (4:size 7332 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:kill ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487788 ) (6:c_time 10:1245722615 ) (6:m_time 10:1245722615 ) (4:size 11196 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:rmdir ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608894 ) (6:c_time 10:1241449488 ) (6:m_time 10:1241449488 ) (4:size 33300 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 12:dbus-monitor ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1248833066 ) (6:m_time 10:1248833066 ) (4:size 13364 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 9:dbus-send ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1248833043 ) (6:m_time 10:1248833043 ) (4:size 16924 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:false ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449472 ) (6:m_time 10:1241449472 ) (4:size 29844 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:grep ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1241449456 ) (6:m_time 10:1241449456 ) (4:size 85612 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:sync ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449447 ) (6:m_time 10:1241449447 ) (4:size 30428 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:echo ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608886 ) (6:c_time 10:1241449475 ) (6:m_time 10:1241449475 ) (4:size 33192 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:dmesg ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1245722617 ) (6:m_time 10:1245722617 ) (4:size 6944 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 3:cat ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609705 ) (6:c_time 10:1241449472 ) (6:m_time 10:1241449472 ) (4:size 55184 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:stty ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 56496 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 15:redhat_lsb_init ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1257424731 ) (6:m_time 10:1257424731 ) (4:size 576 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 6:gunzip ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609705 ) (6:c_time 10:1241444103 ) (6:m_time 10:1241444103 ) (4:size 61 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:ed ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796589 ) (6:c_time 10:1241449424 ) (6:m_time 10:1241449424 ) (4:size 45704 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:touch ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608887 ) (6:c_time 10:1241449454 ) (6:m_time 10:1241449454 ) (4:size 55920 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:view ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449459 ) (6:m_time 10:1241449459 ) (4:size 697592 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:vi ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449459 ) (6:m_time 10:1241449459 ) (4:size 697592 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 13:ntfs-3g.probe ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449423 ) (6:m_time 10:1241449423 ) (4:size 8144 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:gawk ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608935 ) (6:c_time 10:1241449446 ) (6:m_time 10:1241449446 ) (4:size 337712 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:bash ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610010 ) (6:c_time 10:1241449463 ) (6:m_time 10:1241449463 ) (4:size 756360 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 2:ps ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449459 ) (6:m_time 10:1241449459 ) (4:size 81672 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 7:ntfs-3g ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449431 ) (6:m_time 10:1241449431 ) (4:size 36844 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:true ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449451 ) (6:m_time 10:1241449451 ) (4:size 29844 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 5:mkdir ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608924 ) (6:c_time 10:1241449488 ) (6:m_time 10:1241449488 ) (4:size 39804 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 6:doexec ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449493 ) (6:m_time 10:1241449493 ) (4:size 4952 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 8:loadkeys ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449423 ) (6:m_time 10:1241449423 ) (4:size 85132 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 4:date ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610010 ) (6:c_time 10:1241449465 ) (6:m_time 10:1241449465 ) (4:size 68320 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 6:mktemp ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609705 ) (6:c_time 10:1241449468 ) (6:m_time 10:1241449468 ) (4:size 41764 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/bin ) (8:filename 12:iptables-xml ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796590 ) (6:c_time 10:1241449453 ) (6:m_time 10:1241449453 ) (4:size 15760 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 1:/ ) (8:filename 9:.autofsck ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1254209892 ) (6:c_time 10:1252497704 ) (6:m_time 10:1252497704 ) (4:size 0 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 40:initrd-2.6.27.37-170.2.104.fc10.i686.img ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257424636 ) (6:c_time 10:1257424639 ) (6:m_time 10:1257424639 ) (4:size 4206957 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 39:System.map-2.6.27.30-170.2.82.fc10.i686 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1251108122 ) (6:c_time 10:1251108111 ) (6:m_time 10:1251108111 ) (4:size 1094593 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 39:System.map-2.6.27.29-170.2.79.fc10.i686 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1250501479 ) (6:c_time 10:1250501474 ) (6:m_time 10:1250501474 ) (4:size 1094593 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 39:initrd-2.6.27.30-170.2.82.fc10.i686.img ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1251108133 ) (6:c_time 10:1251108136 ) (6:m_time 10:1251108136 ) (4:size 4207682 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 10:xen-3.3.gz ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1220009570 ) (6:c_time 10:1242656443 ) (6:m_time 10:1242656443 ) (4:size 451726 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 36:vmlinuz-2.6.27.30-170.2.82.fc10.i686 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1250513191 ) (6:c_time 10:1251108111 ) (6:m_time 10:1251108111 ) (4:size 2583664 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/boot ) (8:filename 35:config-2.6.27.29-170.2.79.fc10.i686 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1250299135 ) (6:c_time 10:1250501474 ) (6:m_time 10:1250501474 ) (4:size 90946 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 36:config-2.6.27.37-170.2.104.fc10.i686 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1255399728 ) (6:c_time 10:1257424616 ) (6:m_time 10:1257424616 ) (4:size 90951 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 35:config-2.6.27.30-170.2.82.fc10.i686 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1250513191 ) (6:c_time 10:1251108111 ) (6:m_time 10:1251108111 ) (4:size 90919 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 39:initrd-2.6.27.29-170.2.79.fc10.i686.img ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1250501488 ) (6:c_time 10:1250501492 ) (6:m_time 10:1250501492 ) (4:size 4208274 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 37:vmlinuz-2.6.27.37-170.2.104.fc10.i686 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1255399728 ) (6:c_time 10:1257424616 ) (6:m_time 10:1257424616 ) (4:size 2583632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/boot ) (8:filename 12:xen-syms-3.3 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1220009570 ) (6:c_time 10:1242656443 ) (6:m_time 10:1242656443 ) (4:size 6409436 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 40:System.map-2.6.27.37-170.2.104.fc10.i686 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257424625 ) (6:c_time 10:1257424616 ) (6:m_time 10:1257424616 ) (4:size 1094702 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/boot ) (8:filename 36:vmlinuz-2.6.27.29-170.2.79.fc10.i686 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1250299135 ) (6:c_time 10:1250501474 ) (6:m_time 10:1250501474 ) (4:size 2583664 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:lvmdiskscan ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:fsck.ext2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833061 ) (6:m_time 10:1248833061 ) (4:size 185824 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:slattach ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1250042595 ) (6:m_time 10:1250042595 ) (4:size 33748 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:mkdosfs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449446 ) (6:m_time 10:1241449446 ) (4:size 30160 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 15:dhclient-script ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1252500555 ) (6:m_time 10:1252500555 ) (4:size 19526 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:lvreduce ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:ctrlaltdel ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1245722615 ) (6:m_time 10:1245722615 ) (4:size 5996 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 12:matchpathcon ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449497 ) (6:m_time 10:1241449497 ) (4:size 8184 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:cciss_id ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449487 ) (6:m_time 10:1241449487 ) (4:size 8344 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 14:change_console ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241447969 ) (6:m_time 10:1241447969 ) (4:size 379 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 14:grub-md5-crypt ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241448216 ) (6:m_time 10:1241448216 ) (4:size 2293 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:quotaon ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241444869 ) (6:m_time 10:1241444869 ) (4:size 68192 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:setpci ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1243995107 ) (6:m_time 10:1243995107 ) (4:size 14772 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:pccardctl ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449496 ) (6:m_time 10:1241449496 ) (4:size 33056 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 3:vgs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 2:ip ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449444 ) (6:m_time 10:1241449444 ) (4:size 220008 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:rrestore ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833069 ) (6:m_time 10:1248833069 ) (4:size 118896 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:fsck.msdos ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449493 ) (6:m_time 10:1241449493 ) (4:size 54192 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 17:mdassemble.static ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248778219 ) (6:m_time 10:1248778219 ) (4:size 746436 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 12:mkfs.ext4dev ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833070 ) (6:m_time 10:1248833070 ) (4:size 56572 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:lvmdump ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241443997 ) (6:m_time 10:1241443997 ) (4:size 5752 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:chkconfig ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449446 ) (6:m_time 10:1241449446 ) (4:size 28000 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:sfdisk ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1245722618 ) (6:m_time 10:1245722618 ) (4:size 57776 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 17:pam_console_apply ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262603475 ) (6:c_time 10:1246327418 ) (6:m_time 10:1246327418 ) (4:size 38744 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 12:vgcfgrestore ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:udevadm ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449484 ) (6:m_time 10:1241449484 ) (4:size 98000 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:lvextend ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:reboot ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449488 ) (6:m_time 10:1241449488 ) (4:size 50316 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:lsinitrd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248778208 ) (6:m_time 10:1248778208 ) (4:size 510 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:rsyslogd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1249092189 ) (6:m_time 10:1249092189 ) (4:size 294420 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:mkswap ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833053 ) (6:m_time 10:1248833053 ) (4:size 16564 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:lsmod ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449446 ) (6:m_time 10:1241449446 ) (4:size 6544 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 14:new-kernel-pkg ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248778225 ) (6:m_time 10:1248778225 ) (4:size 12451 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:umount.hal ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833062 ) (6:m_time 10:1248833062 ) (4:size 7632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:ethtool ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449446 ) (6:m_time 10:1241449446 ) (4:size 172588 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:ifrename ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449472 ) (6:m_time 10:1241449472 ) (4:size 27036 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:plymouthd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1245463480 ) (6:m_time 10:1245463480 ) (4:size 38408 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:mdassemble ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833062 ) (6:m_time 10:1248833062 ) (4:size 77872 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 13:iptables-save ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449448 ) (6:m_time 10:1241449448 ) (4:size 65292 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:mpath_wait ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241444006 ) (6:m_time 10:1241444006 ) (4:size 366 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:dosfsck ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449493 ) (6:m_time 10:1241449493 ) (4:size 54192 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:shutdown ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449464 ) (6:m_time 10:1241449464 ) (4:size 62820 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:auditd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1246267698 ) (6:m_time 10:1246267698 ) (4:size 170028 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:mke2fs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833070 ) (6:m_time 10:1248833070 ) (4:size 56572 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:quotacheck ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241444869 ) (6:m_time 10:1241444869 ) (4:size 98084 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:netreport ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449494 ) (6:m_time 10:1241449494 ) (4:size 6112 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:rdump ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833037 ) (6:m_time 10:1248833037 ) (4:size 77900 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:mkfs.ext2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833070 ) (6:m_time 10:1248833070 ) (4:size 56572 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:pam_tally2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1246327413 ) (6:m_time 10:1246327413 ) (4:size 11668 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:nash ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1252548237 ) (6:m_time 10:1252548237 ) (4:size 94892 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:mount.fuse ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1257476697 ) (6:m_time 10:1257476697 ) (4:size 8428 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:nameif ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 11120 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:pvdisplay ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:mount.ntfs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449475 ) (6:m_time 10:1241449475 ) (4:size 36848 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:pvremove ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:poweroff ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449488 ) (6:m_time 10:1241449488 ) (4:size 50316 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:iwlist ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449487 ) (6:m_time 10:1241449487 ) (4:size 31208 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 12:install-info ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449416 ) (6:m_time 10:1241449416 ) (4:size 37944 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:partprobe ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833050 ) (6:m_time 10:1248833050 ) (4:size 21572 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:genhostid ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449428 ) (6:m_time 10:1241449428 ) (4:size 5532 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:grubby ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1252548238 ) (6:m_time 10:1252548238 ) (4:size 43076 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:fsck.vfat ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449493 ) (6:m_time 10:1241449493 ) (4:size 54192 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:runuser ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1246327414 ) (6:m_time 10:1246327414 ) (4:size 40868 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:lvmsadc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:tune2fs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833061 ) (6:m_time 10:1248833061 ) (4:size 35700 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:umount.cifs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1257424740 ) (6:m_time 10:1257424740 ) (4:size 14132 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:mkfs.ext4 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833070 ) (6:m_time 10:1248833070 ) (4:size 56572 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 12:fstab-decode ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449484 ) (6:m_time 10:1241449484 ) (4:size 5884 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:e2undo ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833052 ) (6:m_time 10:1248833052 ) (4:size 9876 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:dumpe2fs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833062 ) (6:m_time 10:1248833062 ) (4:size 16640 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:fsadm ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241443997 ) (6:m_time 10:1241443997 ) (4:size 11070 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:ifconfig ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608935 ) (6:c_time 10:1250042595 ) (6:m_time 10:1250042595 ) (4:size 71788 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:hwclock ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1246327415 ) (6:m_time 10:1246327415 ) (4:size 37572 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:mkfs.cramfs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722606 ) (6:m_time 10:1245722606 ) (4:size 18808 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:mdadm ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833063 ) (6:m_time 10:1248833063 ) (4:size 207664 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:iwspy ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449447 ) (6:m_time 10:1241449447 ) (4:size 10856 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 21:pcmcia-socket-startup ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449472 ) (6:m_time 10:1241449472 ) (4:size 38432 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:consoletype ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 5332 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 12:grub-install ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241448216 ) (6:m_time 10:1241448216 ) (4:size 17645 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:swapon ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833054 ) (6:m_time 10:1248833054 ) (4:size 22540 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:ifdown ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241444333 ) (6:m_time 10:1241444333 ) (4:size 924 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:resize2fs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833063 ) (6:m_time 10:1248833063 ) (4:size 36996 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 13:installkernel ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248778225 ) (6:m_time 10:1248778225 ) (4:size 2539 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:vgscan ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 2:tc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449446 ) (6:m_time 10:1241449446 ) (4:size 249232 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:debugfs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833053 ) (6:m_time 10:1248833053 ) (4:size 80920 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:dmraid ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449447 ) (6:m_time 10:1241449447 ) (4:size 229648 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:vgrename ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:fdisk ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722605 ) (6:m_time 10:1245722605 ) (4:size 99052 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 13:insmod.static ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241448073 ) (6:m_time 10:1241448073 ) (4:size 562624 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:iscsid ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1242698704 ) (6:m_time 10:1242698704 ) (4:size 193584 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:iwconfig ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449464 ) (6:m_time 10:1241449464 ) (4:size 24992 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:halt ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449488 ) (6:m_time 10:1241449488 ) (4:size 50316 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 17:ip6tables-restore ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449493 ) (6:m_time 10:1241449493 ) (4:size 65596 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:mkfs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722610 ) (6:m_time 10:1245722610 ) (4:size 7424 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:netplugd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 24724 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:lvchange ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:logsave ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833056 ) (6:m_time 10:1248833056 ) (4:size 8824 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 15:ip6tables-multi ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449485 ) (6:m_time 10:1241449485 ) (4:size 70120 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:losetup ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722600 ) (6:m_time 10:1245722600 ) (4:size 24624 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:mkfs.ntfs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1257476687 ) (6:m_time 10:1257476687 ) (4:size 90252 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:stop ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449485 ) (6:m_time 10:1241449485 ) (4:size 78924 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:modprobe ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262603475 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 95180 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:iscsi-iname ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1242698718 ) (6:m_time 10:1242698718 ) (4:size 9552 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:lvscan ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:vgdisplay ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:vgck ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:rmmod ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449490 ) (6:m_time 10:1241449490 ) (4:size 9912 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:multipathd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449476 ) (6:m_time 10:1241449476 ) (4:size 50600 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:pvchange ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:service ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241444333 ) (6:m_time 10:1241444333 ) (4:size 1692 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:cryptsetup ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833067 ) (6:m_time 10:1248833067 ) (4:size 18480 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:findfs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833061 ) (6:m_time 10:1248833061 ) (4:size 35700 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:mkfs.ext3 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833070 ) (6:m_time 10:1248833070 ) (4:size 56572 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:start_udev ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241444338 ) (6:m_time 10:1241444338 ) (4:size 6896 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:mingetty ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449495 ) (6:m_time 10:1241449495 ) (4:size 13836 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:sulogin ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449466 ) (6:m_time 10:1241449466 ) (4:size 18244 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 15:mount.ntfs-fuse ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449475 ) (6:m_time 10:1241449475 ) (4:size 36848 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:dosfslabel ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 48496 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:swapoff ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833054 ) (6:m_time 10:1248833054 ) (4:size 22540 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:runlevel ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449424 ) (6:m_time 10:1241449424 ) (4:size 46776 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:mii-diag ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 18400 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:iwgetid ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449496 ) (6:m_time 10:1241449496 ) (4:size 10420 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:arping ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241447976 ) (6:m_time 10:1241447976 ) (4:size 15156 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:audispd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1246267698 ) (6:m_time 10:1246267698 ) (4:size 95984 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 22:generate-modprobe.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241448073 ) (6:m_time 10:1241448073 ) (4:size 8723 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 3:lvm ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:setfiles ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1244110006 ) (6:m_time 10:1244110006 ) (4:size 22164 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:status ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449485 ) (6:m_time 10:1241449485 ) (4:size 78924 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:setsysfont ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241444333 ) (6:m_time 10:1241444333 ) (4:size 862 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:ipmaddr ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 15092 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:rpcbind ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241444475 ) (6:m_time 10:1241444475 ) (4:size 51588 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:agetty ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722606 ) (6:m_time 10:1245722606 ) (4:size 20272 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:vgmknodes ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:getkey ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449443 ) (6:m_time 10:1241449443 ) (4:size 8564 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 23:pcmcia-check-broken-cis ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449471 ) (6:m_time 10:1241449471 ) (4:size 10752 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 14:iptables-multi ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449496 ) (6:m_time 10:1241449496 ) (4:size 77980 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:rdisc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241447976 ) (6:m_time 10:1241447976 ) (4:size 18692 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:vgreduce ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:blockdev ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722599 ) (6:m_time 10:1245722599 ) (4:size 13708 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:ip6tables ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449486 ) (6:m_time 10:1241449486 ) (4:size 61460 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:vgimport ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:scsi_id ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796634 ) (6:c_time 10:1241449423 ) (6:m_time 10:1241449423 ) (4:size 25500 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:route ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 54128 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 14:ip6tables-save ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1242997517 ) (6:m_time 10:1242997517 ) (4:size 64836 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:lvdisplay ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:fsck ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833057 ) (6:m_time 10:1248833057 ) (4:size 24168 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:rtmon ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449435 ) (6:m_time 10:1241449435 ) (4:size 32488 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:accton ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449486 ) (6:m_time 10:1241449486 ) (4:size 8112 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:fsck.ext3 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833061 ) (6:m_time 10:1248833061 ) (4:size 185824 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:pvresize ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:MAKEDEV ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449497 ) (6:m_time 10:1241449497 ) (4:size 29460 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:iwpriv ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449454 ) (6:m_time 10:1241449454 ) (4:size 12072 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:mkinitrd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248778225 ) (6:m_time 10:1248778225 ) (4:size 48307 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:logd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449472 ) (6:m_time 10:1241449472 ) (4:size 48312 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:grub ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241448216 ) (6:m_time 10:1241448216 ) (4:size 691800 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:mkfs.vfat ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449446 ) (6:m_time 10:1241449446 ) (4:size 30160 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:ether-wake ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 12792 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:ypbind ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833049 ) (6:m_time 10:1248833049 ) (4:size 44276 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:fsck.cramfs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722607 ) (6:m_time 10:1245722607 ) (4:size 9796 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 3:sln ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 562200 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:portreserve ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449424 ) (6:m_time 10:1241449424 ) (4:size 10836 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 12:weak-modules ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241448073 ) (6:m_time 10:1241448073 ) (4:size 17567 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:lvcreate ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 13:dmraid.static ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449447 ) (6:m_time 10:1241449447 ) (4:size 229648 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:sysctl ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449423 ) (6:m_time 10:1241449423 ) (4:size 12896 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:securetty ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449493 ) (6:m_time 10:1241449493 ) (4:size 7668 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:clock ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1246327415 ) (6:m_time 10:1246327415 ) (4:size 37572 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:portrelease ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449424 ) (6:m_time 10:1241449424 ) (4:size 10836 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:parted ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833070 ) (6:m_time 10:1248833070 ) (4:size 89764 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:insmod ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 6828 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:e2fsck ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833061 ) (6:m_time 10:1248833061 ) (4:size 185824 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:rpc.statd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241444753 ) (6:m_time 10:1241444753 ) (4:size 44684 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 16:iptables-restore ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449472 ) (6:m_time 10:1241449472 ) (4:size 65628 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 13:update-pciids ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241443992 ) (6:m_time 10:1241443992 ) (4:size 1754 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 3:rmt ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833037 ) (6:m_time 10:1248833037 ) (4:size 16372 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 3:arp ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 50928 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:e2label ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833061 ) (6:m_time 10:1248833061 ) (4:size 35700 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:rngd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449489 ) (6:m_time 10:1241449489 ) (4:size 11460 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:lvmsar ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 3:cbq ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241443979 ) (6:m_time 10:1241443979 ) (4:size 33558 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:unix_update ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241444088 ) (6:m_time 10:1241444088 ) (4:size 27860 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:vgmerge ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:mii-tool ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 14364 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:pvmove ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:multipath ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449490 ) (6:m_time 10:1241449490 ) (4:size 16616 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:aureport ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1246327418 ) (6:m_time 10:1246327418 ) (4:size 144204 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:dhcp6c ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241448365 ) (6:m_time 10:1241448365 ) (4:size 148888 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:iptables ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449471 ) (6:m_time 10:1241449471 ) (4:size 61492 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:nologin ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722606 ) (6:m_time 10:1245722606 ) (4:size 5388 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:addpart ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722612 ) (6:m_time 10:1245722612 ) (4:size 5980 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 13:microcode_ctl ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449477 ) (6:m_time 10:1241449477 ) (4:size 12148 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:quotaoff ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241444869 ) (6:m_time 10:1241444869 ) (4:size 68192 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 13:mount.ntfs-3g ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449475 ) (6:m_time 10:1241449475 ) (4:size 36848 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:pam_tally ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449481 ) (6:m_time 10:1241449481 ) (4:size 9768 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:pvscan ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:dhclient ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1252548233 ) (6:m_time 10:1252548233 ) (4:size 490612 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:mkfs.msdos ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449446 ) (6:m_time 10:1241449446 ) (4:size 30160 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:fuser ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449484 ) (6:m_time 10:1241449484 ) (4:size 25312 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:pvcreate ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 3:lvs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:initctl ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449485 ) (6:m_time 10:1241449485 ) (4:size 78924 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:udevcontrol ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449484 ) (6:m_time 10:1241449484 ) (4:size 98000 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:lspci ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1243995100 ) (6:m_time 10:1243995100 ) (4:size 62412 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:vgremove ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:blkid ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833059 ) (6:m_time 10:1248833059 ) (4:size 12884 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:lvmchange ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:ifup ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241444333 ) (6:m_time 10:1241444333 ) (4:size 4227 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:init ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487828 ) (6:c_time 10:1241449482 ) (6:m_time 10:1241449482 ) (4:size 133212 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:pivot_root ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722618 ) (6:m_time 10:1245722618 ) (4:size 5348 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:lvrename ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:vgextend ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:restore ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833069 ) (6:m_time 10:1248833069 ) (4:size 118896 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 12:fsck.ext4dev ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833061 ) (6:m_time 10:1248833061 ) (4:size 185824 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:initlog ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449493 ) (6:m_time 10:1241449493 ) (4:size 19224 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:ausearch ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1246327407 ) (6:m_time 10:1246327407 ) (4:size 157188 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:start ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449485 ) (6:m_time 10:1241449485 ) (4:size 78924 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:restorecon ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1244110006 ) (6:m_time 10:1244110006 ) (4:size 22164 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:mount.cifs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1257424740 ) (6:m_time 10:1257424740 ) (4:size 30868 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:hdparm ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449448 ) (6:m_time 10:1241449448 ) (4:size 78220 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:vconfig ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449475 ) (6:m_time 10:1241449475 ) (4:size 11012 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:modinfo ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449459 ) (6:m_time 10:1241449459 ) (4:size 71036 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:ldconfig ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 734468 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:udevtrigger ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449484 ) (6:m_time 10:1241449484 ) (4:size 98000 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:fixfiles ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1244110006 ) (6:m_time 10:1244110006 ) (4:size 6887 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:delpart ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722608 ) (6:m_time 10:1245722608 ) (4:size 5904 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:fsck.ext4 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1248833061 ) (6:m_time 10:1248833061 ) (4:size 185824 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:lsusb ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449488 ) (6:m_time 10:1241449488 ) (4:size 77196 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:pvck ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:iwevent ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449477 ) (6:m_time 10:1241449477 ) (4:size 14668 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 12:mdadm.static ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248778219 ) (6:m_time 10:1248778219 ) (4:size 886112 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:pidof ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449478 ) (6:m_time 10:1241449478 ) (4:size 13772 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:lvresize ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:auditctl ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1246327413 ) (6:m_time 10:1246327413 ) (4:size 121192 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:lvremove ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:killall5 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449478 ) (6:m_time 10:1241449478 ) (4:size 13772 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:telinit ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449447 ) (6:m_time 10:1241449447 ) (4:size 55640 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:vgexport ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:vgconvert ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:plipconfig ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1250042596 ) (6:m_time 10:1250042596 ) (4:size 7820 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 13:grub-terminfo ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241448216 ) (6:m_time 10:1241448216 ) (4:size 2473 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:ppp-watch ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245290648 ) (6:m_time 10:1245290648 ) (4:size 25488 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:iptunnel ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1250042595 ) (6:m_time 10:1250042595 ) (4:size 19308 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 11:vgcfgbackup ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:depmod ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449490 ) (6:m_time 10:1241449490 ) (4:size 116340 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 4:dump ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833037 ) (6:m_time 10:1248833037 ) (4:size 77900 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:iscsiadm ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1242698716 ) (6:m_time 10:1242698716 ) (4:size 221616 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:badblocks ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833069 ) (6:m_time 10:1248833069 ) (4:size 22772 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:partx ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1245722608 ) (6:m_time 10:1245722608 ) (4:size 19728 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:lvconvert ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:e2image ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833070 ) (6:m_time 10:1248833070 ) (4:size 15852 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:iscsistart ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1242655369 ) (6:m_time 10:1242655369 ) (4:size 890248 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:vgchange ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 9:ifenslave ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449486 ) (6:m_time 10:1241449486 ) (4:size 19532 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:dmsetup ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796627 ) (6:c_time 10:1241449469 ) (6:m_time 10:1241449469 ) (4:size 49068 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:autrace ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796627 ) (6:c_time 10:1246327405 ) (6:m_time 10:1246327405 ) (4:size 95620 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:cfdisk ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796627 ) (6:c_time 10:1245722615 ) (6:m_time 10:1245722615 ) (4:size 63024 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:udevd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796627 ) (6:c_time 10:1241449489 ) (6:m_time 10:1241449489 ) (4:size 89832 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 5:ifcfg ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796627 ) (6:c_time 10:1241443979 ) (6:m_time 10:1241443979 ) (4:size 3056 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:lspcmcia ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449496 ) (6:m_time 10:1241449496 ) (4:size 33056 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 10:udevsettle ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449484 ) (6:m_time 10:1241449484 ) (4:size 98000 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 6:kpartx ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796627 ) (6:c_time 10:1241449466 ) (6:m_time 10:1241449466 ) (4:size 39800 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 3:pvs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 8:vgcreate ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 5:/sbin ) (8:filename 7:vgsplit ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449483 ) (6:m_time 10:1241449483 ) (4:size 651632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libntfs-3g.so.54 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449423 ) (6:m_time 10:1241449423 ) (4:size 291632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 20:libnss_compat-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 36320 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 10:libss.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833053 ) (6:m_time 10:1248833053 ) (4:size 20972 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libcidn-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 191524 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libacl.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449458 ) (6:m_time 10:1241449458 ) (4:size 29780 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 19:libgcrypt.so.11.5.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796653 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 497040 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 18:libkeyutils-1.2.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1241449412 ) (6:m_time 10:1241449412 ) (4:size 8008 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libnss_wins.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1257424688 ) (6:m_time 10:1257424688 ) (4:size 1944188 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 21:libvolume_id.so.1.0.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796634 ) (6:c_time 10:1241449420 ) (6:m_time 10:1241449420 ) (4:size 37048 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libmultipath.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449476 ) (6:m_time 10:1241449476 ) (4:size 208764 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libiw.so.29 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449447 ) (6:m_time 10:1241449447 ) (4:size 32276 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libdb-4.7.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262574187 ) (6:c_time 10:1241449415 ) (6:m_time 10:1241449415 ) (4:size 1500140 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 9:ld-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 156948 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libresolv-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608892 ) (6:c_time 10:1241449412 ) (6:m_time 10:1241449412 ) (4:size 94316 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libproc-3.2.7.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608298 ) (6:c_time 10:1241449423 ) (6:m_time 10:1241449423 ) (4:size 54980 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libfreebl3.chk ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1253227078 ) (6:c_time 10:1257424421 ) (6:m_time 10:1257424421 ) (4:size 478 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libsemanage.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241447987 ) (6:m_time 10:1241447987 ) (4:size 184204 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libpthread-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 135836 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libglib-2.0.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608830 ) (6:c_time 10:1244772258 ) (6:m_time 10:1244772258 ) (4:size 930292 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 10:libplc4.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1257476666 ) (6:m_time 10:1257476666 ) (4:size 16132 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libnss_db-2.2.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241447992 ) (6:m_time 10:1241447992 ) (4:size 818000 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 10:libnss3.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1257476666 ) (6:m_time 10:1257476666 ) (4:size 1208776 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 19:libnss_files-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 55044 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:ld-linux.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 156948 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libgio-2.0.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608669 ) (6:c_time 10:1245290632 ) (6:m_time 10:1245290632 ) (4:size 470720 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libwrap.so.0.7.6 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262574187 ) (6:c_time 10:1241447949 ) (6:m_time 10:1241447949 ) (4:size 31532 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libplds4.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1257476666 ) (6:m_time 10:1257476666 ) (4:size 11588 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 21:libgpg-error.so.0.4.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262592445 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 13420 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libidn.so.11.5.28 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1241449414 ) (6:m_time 10:1241449414 ) (4:size 202232 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libgcrypt.so.11 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796653 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 497040 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libnspr4.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1257476666 ) (6:m_time 10:1257476666 ) (4:size 232252 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libncursesw.so.5 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608298 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 189636 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 10:libssl3.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1257476666 ) (6:m_time 10:1257476666 ) (4:size 200244 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libnssdbm3.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257767215 ) (6:c_time 10:1257424421 ) (6:m_time 10:1257424421 ) (4:size 158856 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libuuid.so.1.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1248833032 ) (6:m_time 10:1248833032 ) (4:size 15832 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libdb-4.5.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449425 ) (6:m_time 10:1241449425 ) (4:size 1249556 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 19:libnss_winbind.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1257424686 ) (6:m_time 10:1257424686 ) (4:size 26396 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libbz2.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449413 ) (6:m_time 10:1241449413 ) (4:size 71980 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libblkid.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833037 ) (6:m_time 10:1248833037 ) (4:size 46796 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libnssutil3.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1257476666 ) (6:m_time 10:1257476666 ) (4:size 102760 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libudev.so.0.0.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796629 ) (6:c_time 10:1241449459 ) (6:m_time 10:1241449459 ) (4:size 40388 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 20:libdevmapper.so.1.02 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796632 ) (6:c_time 10:1241449426 ) (6:m_time 10:1241449426 ) (4:size 95188 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 3:cpp ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796602 ) (6:c_time 10:1241449437 ) (6:m_time 10:1241449437 ) (4:size 219608 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libpcre.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449436 ) (6:m_time 10:1241449436 ) (4:size 200260 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libsmime3.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1257476666 ) (6:m_time 10:1257476666 ) (4:size 162648 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 19:libgthread-2.0.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608830 ) (6:c_time 10:1245290632 ) (6:m_time 10:1245290632 ) (4:size 16852 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 22:libparted-1.8.so.8.0.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796632 ) (6:c_time 10:1248833039 ) (6:m_time 10:1248833039 ) (4:size 431652 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libgpg-error.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262592445 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 13420 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libasound.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796641 ) (6:c_time 10:1257476666 ) (6:m_time 10:1257476666 ) (4:size 932084 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libpcre.so.0.0.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449436 ) (6:m_time 10:1241449436 ) (4:size 200260 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 21:libnss_nisplus-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 59564 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libuuid.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1248833032 ) (6:m_time 10:1248833032 ) (4:size 15832 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 19:libauparse.so.0.0.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796624 ) (6:c_time 10:1246327413 ) (6:m_time 10:1246327413 ) (4:size 56464 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libtinfo.so.5.6 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 98036 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libaio.so.1.0.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241447986 ) (6:m_time 10:1241447986 ) (4:size 2772 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 26:libgthread-2.0.so.0.1800.4 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608830 ) (6:c_time 10:1245290632 ) (6:m_time 10:1245290632 ) (4:size 16852 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libexpat.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1257476665 ) (6:m_time 10:1257476665 ) (4:size 157712 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 19:libcrypto.so.0.9.8g ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1245722598 ) (6:m_time 10:1245722598 ) (4:size 1350768 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libaudit.so.0.0.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608506 ) (6:c_time 10:1246327405 ) (6:m_time 10:1246327405 ) (4:size 105536 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 19:libgobject-2.0.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608830 ) (6:c_time 10:1245290632 ) (6:m_time 10:1245290632 ) (4:size 267380 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libulockmgr.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1257424445 ) (6:m_time 10:1257424445 ) (4:size 8348 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libpamc.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241444088 ) (6:m_time 10:1241444088 ) (4:size 9928 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libcom_err.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1248833032 ) (6:m_time 10:1248833032 ) (4:size 10968 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 22:libcryptsetup.so.0.0.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833056 ) (6:m_time 10:1248833056 ) (4:size 55224 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 20:libntfs-3g.so.54.0.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1241449423 ) (6:m_time 10:1241449423 ) (4:size 291632 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libexpat.so.1.5.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1257476665 ) (6:m_time 10:1257476665 ) (4:size 157712 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 9:libcap.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 15764 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libdbus-1.so.3 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608830 ) (6:c_time 10:1248833032 ) (6:m_time 10:1248833032 ) (4:size 261728 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:ld-lsb.so.3 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 156948 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libbz2.so.1.0.4 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449413 ) (6:m_time 10:1241449413 ) (4:size 71980 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libcrypt-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608892 ) (6:c_time 10:1241449412 ) (6:m_time 10:1241449412 ) (4:size 49512 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libnss_nis-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 50692 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libpthread.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 135836 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 18:libdbus-1.so.3.4.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608830 ) (6:c_time 10:1248833032 ) (6:m_time 10:1248833032 ) (4:size 261728 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libssl.so.7 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1248833032 ) (6:m_time 10:1248833032 ) (4:size 305076 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 18:libnss_compat.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 36320 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libcap.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 15764 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libss.so.2.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833053 ) (6:m_time 10:1248833053 ) (4:size 20972 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 9:libacl.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449458 ) (6:m_time 10:1241449458 ) (4:size 29780 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libdb_cxx-4.5.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241447964 ) (6:m_time 10:1241447964 ) (4:size 1368736 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libnss_db.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241447992 ) (6:m_time 10:1241447992 ) (4:size 818000 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libnsl-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608892 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 117880 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libnss_dns-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608863 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 25980 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libnss_dns.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608863 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 25980 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libdevmapper.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796632 ) (6:c_time 10:1241449426 ) (6:m_time 10:1241449426 ) (4:size 95188 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libcrypt.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608892 ) (6:c_time 10:1241449412 ) (6:m_time 10:1241449412 ) (4:size 49512 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libm-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 210292 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libnsl.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608892 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 117880 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 20:libnss_hesiod-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 22588 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 9:libm.so.6 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 210292 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libfreebl3.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608934 ) (6:c_time 10:1257424421 ) (6:m_time 10:1257424421 ) (4:size 278348 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 19:libthread_db-1.0.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608753 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 38080 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 18:libnss_hesiod.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 22588 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libsepol.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796632 ) (6:c_time 10:1241449420 ) (6:m_time 10:1241449420 ) (4:size 237440 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libfuse.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796630 ) (6:c_time 10:1257476687 ) (6:m_time 10:1257476687 ) (4:size 178544 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 18:libparted-1.8.so.8 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796632 ) (6:c_time 10:1248833039 ) (6:m_time 10:1248833039 ) (4:size 431652 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libtinfo.so.5 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 98036 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 18:libasound.so.2.0.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796641 ) (6:c_time 10:1257476666 ) (6:m_time 10:1257476666 ) (4:size 932084 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libpopt.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449415 ) (6:m_time 10:1241449415 ) (4:size 34904 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libcidn.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 191524 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libc-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 1809672 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libsoftokn3.chk ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1253227078 ) (6:c_time 10:1257424422 ) (6:m_time 10:1257424422 ) (4:size 478 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:librt-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 48484 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libudev.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796629 ) (6:c_time 10:1241449459 ) (6:m_time 10:1241449459 ) (4:size 40388 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libpopt.so.0.0.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449415 ) (6:m_time 10:1241449415 ) (4:size 34904 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libpam.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608503 ) (6:c_time 10:1246327407 ) (6:m_time 10:1246327407 ) (4:size 46344 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 22:libBrokenLocale-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 7448 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 26:libgobject-2.0.so.0.1800.4 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608830 ) (6:c_time 10:1245290632 ) (6:m_time 10:1245290632 ) (4:size 267380 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 10:libattr.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449435 ) (6:m_time 10:1241449435 ) (4:size 18040 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libidn.so.11 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1241449414 ) (6:m_time 10:1241449414 ) (4:size 202232 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 19:libnss_nisplus.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 59564 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libattr.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449435 ) (6:m_time 10:1241449435 ) (4:size 18040 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 19:libgmodule-2.0.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608669 ) (6:c_time 10:1245290632 ) (6:m_time 10:1245290632 ) (4:size 11612 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libe2p.so.2.3 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833041 ) (6:m_time 10:1248833041 ) (4:size 24544 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libkeyutils.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1241449412 ) (6:m_time 10:1241449412 ) (4:size 8008 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libz.so.1.2.3 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 79376 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libpam.so.0.81.13 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608503 ) (6:c_time 10:1246327407 ) (6:m_time 10:1246327407 ) (4:size 46344 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libe2p.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833041 ) (6:m_time 10:1248833041 ) (4:size 24544 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libncurses.so.5 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1241449425 ) (6:m_time 10:1241449425 ) (4:size 139288 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 9:libc.so.6 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 1809672 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 9:libz.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 79376 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libattr.so.1.1.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449435 ) (6:m_time 10:1241449435 ) (4:size 18040 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 26:libgmodule-2.0.so.0.1800.4 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608669 ) (6:c_time 10:1245290632 ) (6:m_time 10:1245290632 ) (4:size 11612 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libvolume_id.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796634 ) (6:c_time 10:1241449420 ) (6:m_time 10:1241449420 ) (4:size 37048 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libsoftokn3.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608934 ) (6:c_time 10:1257424422 ) (6:m_time 10:1257424422 ) (4:size 238260 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libauparse.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796624 ) (6:c_time 10:1246327413 ) (6:m_time 10:1246327413 ) (4:size 56464 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 28:libgcc_s-4.3.2-20081105.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449412 ) (6:m_time 10:1241449412 ) (4:size 55224 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 21:libpam_misc.so.0.81.3 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796630 ) (6:c_time 10:1246327407 ) (6:m_time 10:1246327407 ) (4:size 10532 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libfuse.so.2.8.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796630 ) (6:c_time 10:1257476687 ) (6:m_time 10:1257476687 ) (4:size 178544 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 20:libulockmgr.so.1.0.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1257424445 ) (6:m_time 10:1257424445 ) (4:size 8348 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 23:libglib-2.0.so.0.1800.4 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608830 ) (6:c_time 10:1244772258 ) (6:m_time 10:1244772258 ) (4:size 930292 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libcrypto.so.7 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1245722598 ) (6:m_time 10:1245722598 ) (4:size 1350768 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libpam_misc.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796630 ) (6:c_time 10:1246327407 ) (6:m_time 10:1246327407 ) (4:size 10532 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libply.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449426 ) (6:m_time 10:1241449426 ) (4:size 81772 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libnss_files.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 55044 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libext2fs.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833037 ) (6:m_time 10:1248833037 ) (4:size 189992 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libssl.so.0.9.8g ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1248833032 ) (6:m_time 10:1248833032 ) (4:size 305076 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libselinux.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 114200 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libdl-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 20460 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libply.so.2.0.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796625 ) (6:c_time 10:1241449426 ) (6:m_time 10:1241449426 ) (4:size 81772 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libnssckbi.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1257424421 ) (6:m_time 10:1257424421 ) (4:size 376288 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libwrap.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262574187 ) (6:c_time 10:1241447949 ) (6:m_time 10:1241447949 ) (4:size 31532 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libnsspem.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1257424421 ) (6:m_time 10:1257424421 ) (4:size 164872 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libanl.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 18232 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libcom_err.so.2.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608864 ) (6:c_time 10:1248833032 ) (6:m_time 10:1248833032 ) (4:size 10968 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libresolv.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608892 ) (6:c_time 10:1241449412 ) (6:m_time 10:1241449412 ) (4:size 94316 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 10:librt.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 48484 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libaio.so.1.0.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241447986 ) (6:m_time 10:1241447986 ) (4:size 2772 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libncurses.so.5.6 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1241449425 ) (6:m_time 10:1241449425 ) (4:size 139288 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libacl.so.1.1.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449458 ) (6:m_time 10:1241449458 ) (4:size 29780 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libext2fs.so.2.4 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833037 ) (6:m_time 10:1248833037 ) (4:size 189992 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libnssdbm3.chk ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1253227078 ) (6:c_time 10:1257424421 ) (6:m_time 10:1257424421 ) (4:size 478 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/lib ) (8:filename 18:libcryptsetup.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833056 ) (6:m_time 10:1248833056 ) (4:size 55224 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libaudit.so.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608506 ) (6:c_time 10:1246327405 ) (6:m_time 10:1246327405 ) (4:size 105536 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 11:libaio.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241447986 ) (6:m_time 10:1241447986 ) (4:size 2772 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 10:libdl.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 20460 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 18:libreadline.so.5.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608753 ) (6:c_time 10:1241449425 ) (6:m_time 10:1241449425 ) (4:size 218640 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libSegFault.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 16504 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libdbus-1.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608830 ) (6:c_time 10:1248833032 ) (6:m_time 10:1248833032 ) (4:size 261728 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libthread_db.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608753 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 38080 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libnss_nis.so.2 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 50692 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 18:libncursesw.so.5.6 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608298 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 189636 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 16:libreadline.so.5 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608753 ) (6:c_time 10:1241449425 ) (6:m_time 10:1241449425 ) (4:size 218640 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 12:libutil.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608892 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 15060 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 20:libBrokenLocale.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 7448 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 22:libgio-2.0.so.0.1800.4 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608669 ) (6:c_time 10:1245290632 ) (6:m_time 10:1245290632 ) (4:size 470720 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libcap.so.2.10 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 15764 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 15:libblkid.so.1.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833037 ) (6:m_time 10:1248833037 ) (4:size 46796 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libanl-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 18232 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 17:libpamc.so.0.81.0 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487807 ) (6:c_time 10:1241444088 ) (6:m_time 10:1241444088 ) (4:size 9928 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 14:libutil-2.9.so ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608892 ) (6:c_time 10:1241449411 ) (6:m_time 10:1241449411 ) (4:size 15060 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/lib ) (8:filename 13:libgcc_s.so.1 ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241449412 ) (6:m_time 10:1241449412 ) (4:size 55224 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 6:wgetrc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262605794 ) (6:c_time 10:1241448099 ) (6:m_time 10:1241448099 ) (4:size 4204 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 14:system-release ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1260469202 ) (6:c_time 10:1242645032 ) (6:m_time 10:1242645032 ) (4:size 30 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 4:mtab ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1261415370 ) (6:m_time 10:1261415370 ) (4:size 471 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 10:anthy-conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1251462610 ) (6:c_time 10:1252500540 ) (6:m_time 10:1252500540 ) (4:size 245 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 14:logrotate.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262574187 ) (6:c_time 10:1241448075 ) (6:m_time 10:1241448075 ) (4:size 662 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 17:gpm-twiddler.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241443973 ) (6:m_time 10:1241443973 ) (4:size 4763 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 20:gnome-vfs-mime-magic ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241448008 ) (6:m_time 10:1241448008 ) (4:size 10793 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:rc1.d ) (4:type 9:directory ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257956157 ) (6:c_time 10:1257424476 ) (6:m_time 10:1257424476 ) (4:size 4096 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:idmapd.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252497707 ) (6:c_time 10:1241448089 ) (6:m_time 10:1241448089 ) (4:size 3072 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:issue ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252497720 ) (6:c_time 10:1242645032 ) (6:m_time 10:1242645032 ) (4:size 55 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:hosts.allow ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262574187 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 370 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 13:updatedb.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262574188 ) (6:c_time 10:1241447991 ) (6:m_time 10:1241447991 ) (4:size 186 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:passwd- ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259937120 ) (6:c_time 10:1259937120 ) (6:m_time 10:1259937120 ) (4:size 1970 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:fstab ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261415379 ) (6:c_time 10:1241443487 ) (6:m_time 10:1241443487 ) (4:size 1109 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 14:scsi_id.config ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241444338 ) (6:m_time 10:1241444338 ) (4:size 666 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:printcap ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1255699081 ) (6:m_time 10:1255699081 ) (4:size 195 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 12:rsyslog.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487788 ) (6:c_time 10:1249035748 ) (6:m_time 10:1249035748 ) (4:size 2741 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:cron.deny ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1251718590 ) (6:c_time 10:1243352757 ) (6:m_time 10:1243352757 ) (4:size 0 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:exports~ ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1244727944 ) (6:c_time 10:1244727944 ) (6:m_time 10:1244727944 ) (4:size 37 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:sudoers ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259937766 ) (6:c_time 10:1259937435 ) (6:m_time 10:1259937435 ) (4:size 528 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:sos.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252432197 ) (6:c_time 10:1257424591 ) (6:m_time 10:1257424591 ) (4:size 262 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:services ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262605397 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 418412 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:screenrc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262603571 ) (6:c_time 10:1241445229 ) (6:m_time 10:1241445229 ) (4:size 7299 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:foo.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1256904952 ) (6:c_time 10:1256904952 ) (6:m_time 10:1256904952 ) (4:size 0 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:rc6.d ) (4:type 9:directory ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257956157 ) (6:c_time 10:1257424476 ) (6:m_time 10:1257424476 ) (4:size 4096 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 28:pm-utils-hd-apm-restore.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448263 ) (6:m_time 10:1241448263 ) (4:size 370 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 16:DIR_COLORS.xterm ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1241444084 ) (6:m_time 10:1241444084 ) (4:size 3646 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:resolv.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1258220094 ) (6:m_time 10:1258220094 ) (4:size 303 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:yp.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1239186560 ) (6:c_time 10:1242997448 ) (6:m_time 10:1242997448 ) (4:size 585 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:rc2.d ) (4:type 9:directory ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1260969885 ) (6:c_time 10:1257424476 ) (6:m_time 10:1257424476 ) (4:size 4096 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:localtime ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241441771 ) (6:m_time 10:1241441771 ) (4:size 2246 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:inputrc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 801 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 6:passwd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1259937120 ) (6:m_time 10:1259937120 ) (4:size 2019 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:rc.local ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1255704644 ) (6:c_time 10:1241444333 ) (6:m_time 10:1241444333 ) (4:size 220 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:environment ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608506 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 0 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:fb.modes ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448484 ) (6:m_time 10:1241448484 ) (4:size 22060 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:dumpdates ) (4:type 7:regular ) (8:group_id 1:6 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241447990 ) (6:m_time 10:1241447990 ) (4:size 0 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]1 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 12:Muttrc.local ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448486 ) (6:m_time 10:1241448486 ) (4:size 32 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 6:ethers ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1247735110 ) (6:c_time 10:1249985152 ) (6:m_time 10:1249985152 ) (4:size 28 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 12:gpm-syn.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241443973 ) (6:m_time 10:1241443973 ) (4:size 1582 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:issue.net ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1226001998 ) (6:c_time 10:1242645032 ) (6:m_time 10:1242645032 ) (4:size 54 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:hosts ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1242655008 ) (6:m_time 10:1242655008 ) (4:size 249 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:asound.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1221054154 ) (6:c_time 10:1257424428 ) (6:m_time 10:1257424428 ) (4:size 148 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 10:DIR_COLORS ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261566494 ) (6:c_time 10:1241444084 ) (6:m_time 10:1241444084 ) (4:size 3921 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 10:irssi.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1238532602 ) (6:c_time 10:1252500556 ) (6:m_time 10:1252500556 ) (4:size 6560 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 10:anacrontab ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262577784 ) (6:c_time 10:1241444870 ) (6:m_time 10:1241444870 ) (4:size 321 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:profile~ ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446856 ) (6:c_time 10:1241446856 ) (6:m_time 10:1241446856 ) (4:size 1053 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 6:init.d ) (4:type 9:directory ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257956157 ) (6:c_time 10:1257424686 ) (6:m_time 10:1257424686 ) (4:size 4096 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 12:pam_smb.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1242655032 ) (6:c_time 10:1241447998 ) (6:m_time 10:1241447998 ) (4:size 12 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:sysctl.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1260969885 ) (6:c_time 10:1241444333 ) (6:m_time 10:1241444333 ) (4:size 604 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 14:fedora-release ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1260469202 ) (6:c_time 10:1242645032 ) (6:m_time 10:1242645032 ) (4:size 30 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 12:enscript.cfg ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448484 ) (6:m_time 10:1241448484 ) (4:size 4843 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 10:login.defs ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259937120 ) (6:c_time 10:1241448807 ) (6:m_time 10:1241448807 ) (4:size 1524 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 10:rc.sysinit ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252497704 ) (6:c_time 10:1241444333 ) (6:m_time 10:1241444333 ) (4:size 23996 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 12:prelink.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262487801 ) (6:c_time 10:1241448195 ) (6:m_time 10:1241448195 ) (4:size 789 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:netconfig ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252497706 ) (6:c_time 10:1241443994 ) (6:m_time 10:1241443994 ) (4:size 768 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:rc5.d ) (4:type 9:directory ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1260969885 ) (6:c_time 10:1257424476 ) (6:m_time 10:1257424476 ) (4:size 4096 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 6:Muttrc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448486 ) (6:m_time 10:1241448486 ) (4:size 121356 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 13:gpm-root.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241443973 ) (6:m_time 10:1241443973 ) (4:size 1756 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:profile ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1241446856 ) (6:m_time 10:1241446856 ) (4:size 1098 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:group ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1259937120 ) (6:m_time 10:1259937120 ) (4:size 842 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 4:virc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259681176 ) (6:c_time 10:1241443998 ) (6:m_time 10:1241443998 ) (4:size 1962 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:esd.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241444143 ) (6:m_time 10:1241444143 ) (4:size 368 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:ld.so.cache ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1258040993 ) (6:m_time 10:1258040993 ) (4:size 71666 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:yum.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262592445 ) (6:c_time 10:1257424694 ) (6:m_time 10:1257424694 ) (4:size 791 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 4:motd ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261566494 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 0 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 14:warnquota.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241444869 ) (6:m_time 10:1241444869 ) (4:size 2919 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:crypttab ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252497703 ) (6:c_time 10:1241448810 ) (6:m_time 10:1241448810 ) (4:size 89 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:ldap.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1243333256 ) (6:c_time 10:1241448807 ) (6:m_time 10:1241448807 ) (4:size 9122 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:mail.rc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448085 ) (6:m_time 10:1241448085 ) (4:size 1909 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:vimrc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1251721475 ) (6:c_time 10:1241444007 ) (6:m_time 10:1241444007 ) (4:size 1962 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:koji.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259681255 ) (6:c_time 10:1241444326 ) (6:m_time 10:1241444326 ) (4:size 579 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 6:shadow ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608506 ) (6:c_time 10:1259937276 ) (6:m_time 10:1259937276 ) (4:size 1856 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 15:sudoers.rpmsave ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1258973932 ) (6:c_time 10:1258973932 ) (6:m_time 10:1258973932 ) (4:size 3761 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:jwhois.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259858506 ) (6:c_time 10:1241447992 ) (6:m_time 10:1241447992 ) (4:size 31011 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:aliases ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 1512 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 14:multipath.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241444006 ) (6:m_time 10:1241444006 ) (4:size 2705 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:nscd.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241444590 ) (6:m_time 10:1241444590 ) (4:size 2144 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:dhcp6c.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448365 ) (6:m_time 10:1241448365 ) (4:size 178 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 6:group- ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259937120 ) (6:c_time 10:1259937120 ) (6:m_time 10:1259937120 ) (4:size 824 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 13:prelink.cache ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262574188 ) (6:c_time 10:1262487828 ) (6:m_time 10:1262487828 ) (4:size 409430 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 13:a2ps-site.cfg ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448755 ) (6:m_time 10:1241448755 ) (4:size 2562 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:quotatab ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241444869 ) (6:m_time 10:1241444869 ) (4:size 257 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:csh.login ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 873 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:sudoers~ ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259937230 ) (6:c_time 10:1259937230 ) (6:m_time 10:1259937230 ) (4:size 3703 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:ntp.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1255704644 ) (6:c_time 10:1241441767 ) (6:m_time 10:1241441767 ) (4:size 1967 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 6:my.cnf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1249275490 ) (6:c_time 10:1251108063 ) (6:m_time 10:1251108063 ) (4:size 849 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:protocols ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261566488 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 6377 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 6:shells ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257424585 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 32 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:securetty ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1223656179 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 122 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 13:brewkoji.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259681255 ) (6:c_time 10:1259674821 ) (6:m_time 10:1259674821 ) (4:size 212 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 12:dnsmasq.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257424475 ) (6:c_time 10:1257424471 ) (6:m_time 10:1257424471 ) (4:size 19253 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 10:man.config ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609705 ) (6:c_time 10:1241448252 ) (6:m_time 10:1241448252 ) (4:size 4940 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 14:quotagrpadmins ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241444869 ) (6:m_time 10:1241444869 ) (4:size 220 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 3:rmt ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261796626 ) (6:c_time 10:1248833037 ) (6:m_time 10:1248833037 ) (4:size 16372 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:statetab ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1251718572 ) (6:c_time 10:1241444333 ) (6:m_time 10:1241444333 ) (4:size 212 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:html2psrc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448544 ) (6:m_time 10:1241448544 ) (4:size 298 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:mke2fs.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1219637715 ) (6:c_time 10:1248778209 ) (6:m_time 10:1248778209 ) (4:size 803 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 16:gssapi_mech.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448085 ) (6:m_time 10:1241448085 ) (4:size 801 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 12:initlog.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1251718572 ) (6:c_time 10:1241444332 ) (6:m_time 10:1241444332 ) (4:size 658 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:inittab ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1256053027 ) (6:c_time 10:1241448808 ) (6:m_time 10:1241448808 ) (4:size 853 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 10:aliases.db ) (4:type 7:regular ) (8:group_id 2:51 ) (7:user_id 1:0 ) (6:a_time 10:1262574187 ) (6:c_time 10:1241444590 ) (6:m_time 10:1241444590 ) (4:size 12288 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 19:DIR_COLORS.256color ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1251718558 ) (6:c_time 10:1241444084 ) (6:m_time 10:1241444084 ) (4:size 4919 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 10:hosts.deny ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262574187 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 645 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:rwtab ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1251718572 ) (6:c_time 10:1241444333 ) (6:m_time 10:1241444333 ) (4:size 847 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:papersize ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1260800031 ) (6:c_time 10:1241447984 ) (6:m_time 10:1241447984 ) (4:size 68 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 12:libuser.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257424585 ) (6:c_time 10:1241448807 ) (6:m_time 10:1241448807 ) (4:size 2293 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 13:nsswitch.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 1696 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:slrn.rc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241447990 ) (6:m_time 10:1241447990 ) (4:size 21599 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:at.deny ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1251718575 ) (6:c_time 10:1241448099 ) (6:m_time 10:1241448099 ) (4:size 1 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 18:system-release-cpe ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1226001998 ) (6:c_time 10:1242645032 ) (6:m_time 10:1242645032 ) (4:size 33 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 15:kerneloops.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252497716 ) (6:c_time 10:1242645355 ) (6:m_time 10:1242645355 ) (4:size 1085 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 6:bashrc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262609667 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 1637 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:.pwd.lock ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447968 ) (6:c_time 10:1241447968 ) (6:m_time 10:1241447968 ) (4:size 0 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 12:urlview.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241447984 ) (6:m_time 10:1241447984 ) (4:size 313 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 3:rpc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252497706 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 1615 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:filesystems ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 59 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 14:Trolltech.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1205365095 ) (6:c_time 10:1257424422 ) (6:m_time 10:1257424422 ) (4:size 45 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:adjtime ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1242657761 ) (6:c_time 10:1242657763 ) (6:m_time 10:1242657763 ) (4:size 46 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 10:mime.types ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262605365 ) (6:c_time 10:1241447921 ) (6:m_time 10:1241447921 ) (4:size 14327 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:pinforc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448190 ) (6:m_time 10:1241448190 ) (4:size 2872 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:favicon.png ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257424789 ) (6:c_time 10:1241448107 ) (6:m_time 10:1241448107 ) (4:size 558 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:a2ps.cfg ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448755 ) (6:m_time 10:1241448755 ) (4:size 15188 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 10:ld.so.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608935 ) (6:c_time 10:1241443939 ) (6:m_time 10:1241443939 ) (4:size 28 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:smartd.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448365 ) (6:m_time 10:1241448365 ) (4:size 6463 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:lftp.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1234892824 ) (6:c_time 10:1248778299 ) (6:m_time 10:1248778299 ) (4:size 3534 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:shadow- ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259937120 ) (6:c_time 10:1259937120 ) (6:m_time 10:1259937120 ) (4:size 1727 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:rc0.d ) (4:type 9:directory ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257956157 ) (6:c_time 10:1257424476 ) (6:m_time 10:1257424476 ) (4:size 4096 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:exports ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1255704670 ) (6:c_time 10:1244727944 ) (6:m_time 10:1244727944 ) (4:size 38 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 13:sestatus.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1243352375 ) (6:c_time 10:1244110006 ) (6:m_time 10:1244110006 ) (4:size 216 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:gshadow- ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259937120 ) (6:c_time 10:1259937120 ) (6:m_time 10:1259937120 ) (4:size 679 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:ltrace.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241446999 ) (6:c_time 10:1241447992 ) (6:m_time 10:1241447992 ) (4:size 10814 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:host.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262610011 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 17 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 8:networks ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1261406925 ) (6:c_time 10:1241444332 ) (6:m_time 10:1241444332 ) (4:size 58 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:krb5.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259681255 ) (6:c_time 10:1241447263 ) (6:m_time 10:1241447263 ) (4:size 662 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:grub.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1257424762 ) (6:c_time 10:1257424762 ) (6:m_time 10:1257424762 ) (4:size 1044 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 13:sensors3.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1241447000 ) (6:c_time 10:1241448417 ) (6:m_time 10:1241448417 ) (4:size 71449 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:rc4.d ) (4:type 9:directory ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1260969885 ) (6:c_time 10:1257424476 ) (6:m_time 10:1257424476 ) (4:size 4096 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:sudoers.tmp ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259937402 ) (6:c_time 10:1259937402 ) (6:m_time 10:1259937402 ) (4:size 3704 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 2:rc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252497720 ) (6:c_time 10:1241444333 ) (6:m_time 10:1241444333 ) (4:size 2596 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:mailcap ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259671010 ) (6:c_time 10:1241447921 ) (6:m_time 10:1241447921 ) (4:size 272 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 13:libaudit.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1240339640 ) (6:c_time 10:1246267626 ) (6:m_time 10:1246267626 ) (4:size 191 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 11:reader.conf ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252497709 ) (6:c_time 10:1252497709 ) (6:m_time 10:1252497709 ) (4:size 435 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 9:csh.cshrc ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1256053026 ) (6:c_time 10:1241443925 ) (6:m_time 10:1241443925 ) (4:size 1476 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 5:rc3.d ) (4:type 9:directory ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1262608934 ) (6:c_time 10:1257424476 ) (6:m_time 10:1257424476 ) (4:size 4096 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]1 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]1 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]1 ) ) (9:file_item (4:path 4:/etc ) (8:filename 14:redhat-release ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1260469202 ) (6:c_time 10:1242645032 ) (6:m_time 10:1242645032 ) (4:size 30 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:crontab ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1252497716 ) (6:c_time 10:1241443948 ) (6:m_time 10:1241443948 ) (4:size 255 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]1 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]1 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]1 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) (9:file_item (4:path 4:/etc ) (8:filename 7:gshadow ) (4:type 7:regular ) (8:group_id 1:0 ) (7:user_id 1:0 ) (6:a_time 10:1259937120 ) (6:c_time 10:1259937120 ) (6:m_time 10:1259937120 ) (4:size 694 ) (4:suid 4[bool]0 ) (6:sticky 4[bool]0 ) (5:uread 4[bool]1 ) (6:uwrite 4[bool]0 ) (5:uexec 4[bool]0 ) (5:gread 4[bool]0 ) (6:gwrite 4[bool]0 ) (5:gexec 4[bool]0 ) (5:oread 4[bool]0 ) (6:owrite 4[bool]0 ) (5:oexec 4[bool]0 ) ) ) )
EOF
	ret_val=$?
	
	if [[ $ret_val -ne 0 ]]; then
		echo "test_seap_split: Internal error"
		break
	fi
	
	PARTS=$(ls x*)
	ARGS=$(echo -n $PARTS | sed 's|\([a-zA-Z0-9]*\)|"`cat \1`"|g' | tr '\n' ' ')
	
	eval "\"${EXECDIR}/sexp_parser\" $ARGS" >> "$LOGFILE"
	ret_val=$?
	
	if [[ $ret_val -ne 0 ]]; then
		break
	fi
	
	rm $PARTS
    done
    
    cd "$EXECDIR"
    cp "$TEMPDIR/$LOGFILE" .
    
    return $ret_val
}

# Cleanup.
function test_seap_cleanup { 
    local ret_val=0;
    
    rm -f test_seap_tc01.out \
	  test_seap_tc02.out \
	  test_seap_tc03.out 

    ret_val=$?
    
    return $ret_val
}

# TESTING.

echo ""
echo "--------------------------------------------------"

result=0
log=test_seap.log

exec 2>$log

test_seap_setup  
ret_val=$?
report_result "test_seap_setup" $ret_val 
result=$[$result+$ret_val]

test_seap_incorrect_expression
ret_val=$?
report_result "test_seap_incorrect_expression" $ret_val 
result=$[$result+$ret_val]   

test_seap_correct_expression
ret_val=$? 
report_result "test_seap_correct_expression" $ret_val 
result=$[$result+$ret_val]   

test_seap_string_expression
ret_val=$? 
report_result "test_seap_string_expression" $ret_val 
result=$[$result+$ret_val]   

test_seap_number_expression
ret_val=$? 
report_result "test_seap_number_expression" $ret_val 
result=$[$result+$ret_val]   

test_seap_list_expression
ret_val=$? 
report_result "test_seap_list_expression" $ret_val 
result=$[$result+$ret_val]   

test_seap_split
ret_val=$? 
report_result "test_seap_split" $ret_val  
result=$[$result+$ret_val]

test_seap_cleanup  
ret_val=$? 
report_result "test_seap_cleanup" $ret_val  
result=$[$result+$ret_val]

echo "--------------------------------------------------"
echo "See ${log} (in tests dir)"

exit $result
